# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]
- No unreleased changes so far

## [0.7] - 2026-01-04
### Changed
- CarConnectivity 0.11 compatibility

Note: This plugin is required for compatibility with CarConnectivity version 0.11 and higher.

## [0.6.1] - 2025-11-02
### Changed
- Updated some dependencies

## [0.6] - 2025-04-17
### Changed
- Updated dependencies

## [0.5] - 2025-04-02
### Fixed
- Allowes to have multiple instances of this plugin running
- Pincode provided through configuration

### Changed
- Updated dependencies

## [0.4] - 2025-03-20
### Added
- Added switch to turn on/off window heating
### Changed
- Bump carconnectivity dependency to 0.5

## [0.3] - 2025-03-02
### Added
- Bump carconnectivity dependency to 0.4

## [0.2.1] - 2025-02-20
### Fixed
- Fixes bug due to template ambiguity

### Added
- Plugin UI root

## [0.2] - 2025-02-19
### Added
- Added plugin UI

## [0.1] - 2025-01-25
Initial release, let's go and give this to the public to try out...

[unreleased]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/compare/v0.7...HEAD
[0.7]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.7
[0.6.1]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.6.1
[0.6]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.6
[0.5]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.5
[0.4]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.4
[0.3]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.3
[0.2.1]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.2.1
[0.2]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.2
[0.1]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.1
